# encoding: utf-8
'''
This module contains the meta-data of the package.
'''

__author__ = 'David Kundih'
__copyright__ = 'Copyright © 2021- David Kundih'
__credits__ = [
	'dkundih <https://github.com/dkundih>',

]
__license__ = 'Copyright © 2021- David Kundih. All rights reserved. Licensed under the Apache License, Version 2.0 | For more details about the license and terms of use visit the official duality documentation linked at https://github.com/dkundih/duality and https://pypi.org/project/duality'
__version__ = '2.2.6'
__documentation__ = 'https://github.com/dkundih/duality | https://pypi.org/project/duality'
__contact__ = 'dakundih@unin.hr | kundihdavid@gmail.com'
__donate__ = 'https://patreon.com/dkundih | https://buymeacoffee.com/dkundih'

#general setup confirmation.
def main():
    print('Setup successful.')

if __name__ == '__main__':
        main()